# Utils for Language

* Translation
* Text-To-Speach
* Named Entity Recognition

## Version History

### 1.0.3 (NEXT)

### 1.0.2 (CURRENT)

* Make compatible with utils_base-nuuuwan=1.0.8

### 1.0.1

* Added TTS

### 1.0.0

* Added Translator